API docs for “spamfighter.core.commands.apiglue.JSONRPC_API_Glue”

# Class s.c.c.a.JSONRPC_API_Glue(jsonrpc.JSONRPC, API_Glue):

Part of spamfighter.core.commands.apiglue View Source View In Hierarchy

Ресурс JSON-RPC (Twisted Web), который обрабатывает команды нашего API (минуя стандартные механизмы поиска функции).

Method | _getFunction | Given a string, return a function, or raise jsonrpclib.NoSuchFunction.

Inherited from JSONRPC:

Method | __init__ | Undocumented
Method | putSubHandler | Undocumented
Method | getSubHandler | Undocumented
Method | getSubHandlerPrefixes | Undocumented
Method | render | Undocumented
Method | _cbRender | Undocumented
Method | _ebRender | Undocumented
Method | _listFunctions | Return a list of the names of all jsonrpc methods.

Inherited from API_Glue:

Method | _internalGetFunction | Получить функцию, выполняющую команду с указанным именем и при этом

@jsonrpc_error_translator
def _getFunction(self, functionPath): (source)
overrides spamfighter.txjsonrpc.web.jsonrpc.JSONRPC._getFunction
Given a string, return a function, or raise jsonrpclib.NoSuchFunction.

This returned function will be called, and should return the result of the call, a Deferred, or a Fault instance.

Override in subclasses if you want your own policy. The default policy is that given functionPath 'foo', return the method at self.jsonrpc_foo, i.e. getattr(self, "jsonrpc_" + functionPath). If functionPath contains self.separator, the sub-handler for the initial prefix is used to search for the remaining path.